# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum
from ask_sdk_model.request import Request


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union
    from datetime import datetime


class LoadIndexListDataEvent(Request):
    """
    The LoadIndexListData event is sent to the skill to retrieve additional list items.


    :param request_id: Represents the unique identifier for the specific request.
    :type request_id: (optional) str
    :param timestamp: Provides the date and time when Alexa sent the request as an ISO 8601 formatted string. Used to verify the request when hosting your skill as a web service.
    :type timestamp: (optional) datetime
    :param locale: A string indicating the user’s locale. For example: en-US. This value is only provided with certain request types.
    :type locale: (optional) str
    :param token: The token as specified in the presentation&#39;s RenderDocument directive.
    :type token: (optional) str
    :param correlation_token: An identifier generated by a device that is used to correlate requests with their corresponding response directives.
    :type correlation_token: (optional) str
    :param list_id: The identifier of the list whose items to fetch.
    :type list_id: (optional) str
    :param start_index: The lowest index of the items to fetch (inclusive)
    :type start_index: (optional) int
    :param count: The number of items to fetch. Examples:  startIndex &#x3D; 10, count &#x3D; 2: Skill is expected to return items at indexes 10 and 11. startIndex &#x3D; -2, count &#x3D; 5: Skill is expected to return items at indexes -2, -1, 0, 1 and 2 
    :type count: (optional) int

    """
    deserialized_types = {
        'object_type': 'str',
        'request_id': 'str',
        'timestamp': 'datetime',
        'locale': 'str',
        'token': 'str',
        'correlation_token': 'str',
        'list_id': 'str',
        'start_index': 'int',
        'count': 'int'
    }  # type: Dict

    attribute_map = {
        'object_type': 'type',
        'request_id': 'requestId',
        'timestamp': 'timestamp',
        'locale': 'locale',
        'token': 'token',
        'correlation_token': 'correlationToken',
        'list_id': 'listId',
        'start_index': 'startIndex',
        'count': 'count'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, request_id=None, timestamp=None, locale=None, token=None, correlation_token=None, list_id=None, start_index=None, count=None):
        # type: (Optional[str], Optional[datetime], Optional[str], Optional[str], Optional[str], Optional[str], Optional[int], Optional[int]) -> None
        """The LoadIndexListData event is sent to the skill to retrieve additional list items.

        :param request_id: Represents the unique identifier for the specific request.
        :type request_id: (optional) str
        :param timestamp: Provides the date and time when Alexa sent the request as an ISO 8601 formatted string. Used to verify the request when hosting your skill as a web service.
        :type timestamp: (optional) datetime
        :param locale: A string indicating the user’s locale. For example: en-US. This value is only provided with certain request types.
        :type locale: (optional) str
        :param token: The token as specified in the presentation&#39;s RenderDocument directive.
        :type token: (optional) str
        :param correlation_token: An identifier generated by a device that is used to correlate requests with their corresponding response directives.
        :type correlation_token: (optional) str
        :param list_id: The identifier of the list whose items to fetch.
        :type list_id: (optional) str
        :param start_index: The lowest index of the items to fetch (inclusive)
        :type start_index: (optional) int
        :param count: The number of items to fetch. Examples:  startIndex &#x3D; 10, count &#x3D; 2: Skill is expected to return items at indexes 10 and 11. startIndex &#x3D; -2, count &#x3D; 5: Skill is expected to return items at indexes -2, -1, 0, 1 and 2 
        :type count: (optional) int
        """
        self.__discriminator_value = "Alexa.Presentation.APL.LoadIndexListData"  # type: str

        self.object_type = self.__discriminator_value
        super(LoadIndexListDataEvent, self).__init__(object_type=self.__discriminator_value, request_id=request_id, timestamp=timestamp, locale=locale)
        self.token = token
        self.correlation_token = correlation_token
        self.list_id = list_id
        self.start_index = start_index
        self.count = count

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, LoadIndexListDataEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
